SolarSystem
===========

.. currentmodule:: pywwt.solar_system

.. autoclass:: SolarSystem
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SolarSystem.cosmos
      ~SolarSystem.lighting
      ~SolarSystem.milky_way
      ~SolarSystem.minor_orbits
      ~SolarSystem.objects
      ~SolarSystem.orbits
      ~SolarSystem.scale
      ~SolarSystem.stars

   .. rubric:: Methods Summary

   .. autosummary::

      ~SolarSystem.track_object

   .. rubric:: Attributes Documentation

   .. autoattribute:: cosmos
   .. autoattribute:: lighting
   .. autoattribute:: milky_way
   .. autoattribute:: minor_orbits
   .. autoattribute:: objects
   .. autoattribute:: orbits
   .. autoattribute:: scale
   .. autoattribute:: stars

   .. rubric:: Methods Documentation

   .. automethod:: track_object
